
Digital Signal Analysis (DSA) library for python.
The library includes such methods of signal analysis and
signal parameter estimation as arma-based techniques; 
subspace-based techniques; matrix-pencil-based methods; 
singular-spectrum analysis (SSA); dynamic-mode decomposition (DMD); 
empirical mode decomposition; variational mode decomposition; 
empirical wavelet transform; Hilbert vibration decomposition 
and many others.
